Crate luminol_egui_wgpu

Crate luminol_egui_wgpu 

This crates provides bindings between egui and wgpu.

If you’re targeting WebGL you also need to turn on the webgl feature of the wgpu crate:

# Enable both WebGL and WebGPU backends on web.
wgpu = { version = "*", features = ["webgpu", "webgl"] }

You can control whether WebGL or WebGPU will be picked at runtime by setting WgpuConfiguration::supported_backends. The default is to prefer WebGPU and fall back on WebGL.

Feature flags

  • puffin — Enable profiling with the puffin crate.
  • winit — Enable winit integration. On Linux, requires either wayland or x11
  • wayland — Enables Wayland support for winit.
  • x11 — Enables x11 support for winit.

Re-exports

pub use wgpu;

Modules

winit
Module for painting egui with wgpu on winit.

Structs

Callback
You can use this to do custom wgpu rendering in an egui app.
RenderState
Access to the render state for egui.
Renderer
Renderer for a egui based GUI.
ScreenDescriptor
Information about the screen used for rendering.
WgpuConfiguration
Configuration for using wgpu with eframe or the egui-wgpu winit feature.

Enums

SurfaceErrorAction
Specifies which action should be taken as consequence of a wgpu::SurfaceError
WgpuError
An error produced by egui-wgpu.

Traits

CallbackTrait
A callback trait that can be used to compose an epaint::PaintCallback via Callback for custom WGPU rendering.

Functions

adapter_info_summary
A human-readable summary about an adapter
depth_format_from_bits
Take’s epi’s depth/stencil bits and returns the corresponding wgpu format.
preferred_framebuffer_format
Find the framebuffer format that egui prefers

Type Aliases

CallbackResources
You can use this for storage when implementing CallbackTrait.