This crates provides bindings between egui and wgpu.
If you’re targeting WebGL you also need to turn on the
webgl feature of the wgpu crate:
# Enable both WebGL and WebGPU backends on web.
wgpu = { version = "*", features = ["webgpu", "webgl"] }You can control whether WebGL or WebGPU will be picked at runtime by setting
WgpuConfiguration::supported_backends.
The default is to prefer WebGPU and fall back on WebGL.
Feature flags
Re-exports
pub use wgpu;
Modules
Structs
- Callback
- You can use this to do custom
wgpurendering in an egui app. - Render
State - Access to the render state for egui.
- Renderer
- Renderer for a egui based GUI.
- Screen
Descriptor - Information about the screen used for rendering.
- Wgpu
Configuration - Configuration for using wgpu with eframe or the egui-wgpu winit feature.
Enums
- Surface
Error Action - Specifies which action should be taken as consequence of a
wgpu::SurfaceError - Wgpu
Error - An error produced by egui-wgpu.
Traits
- Callback
Trait - A callback trait that can be used to compose an
epaint::PaintCallbackviaCallbackfor custom WGPU rendering.
Functions
- adapter_
info_ summary - A human-readable summary about an adapter
- depth_
format_ from_ bits - Take’s epi’s depth/stencil bits and returns the corresponding wgpu format.
- preferred_
framebuffer_ format - Find the framebuffer format that egui prefers
Type Aliases
- Callback
Resources - You can use this for storage when implementing
CallbackTrait.